## cdist-type__install_chroot_mount(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__install_chroot_mount - mount a chroot

## 2. DESCRIPTION

Mount and prepare a chroot for running commands within it.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

None.

## 5. EXAMPLES

    __install_chroot_mount /path/to/chroot

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2012 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).